@@ -1,8 +1,23 @@
 
 '%!in%' <- function(x,y)!('%in%'(x,y))
 
-proper=function(x) paste0(toupper(substr(x, 1, 1)),
-                          tolower(substring(x, 2)))
+toproper <- function(x) paste0(toupper(substr(x, 1, 1)),
+                             tolower(substring(x, 2)))
+isproper <- function(word){
+  if(word == toproper(word)){
+    return(TRUE)
+  } else {
+    return(FALSE)
+  }
+}
+
+islower <- function(word){
+  if(word == tolower(word)){
+    return(TRUE)
+  } else {
+    return(FALSE)
+  }
+}
 
 isupper <- function(chr){
   if(chr == toupper(chr)){
@@ -25,11 +40,13 @@ is.empty <- function(val){
   return(FALSE)
 }
 
-rename_column <- function(dat,old,new){
+rename_column <- function(dat,old,new,silent=FALSE){
   if(old %in% colnames(dat)){
     colnames(dat)[which(names(dat) == old)] <- new
   } else {
-    print(paste("Error: Fieldname not found...",old))
+    if(!silent){
+      print(paste("Fieldname not found...",old))
+    }
   }
   return(dat)
 }
